@@ -7,14 +7,12 @@ from lxml import etree
 
 from broadworks_ocip import BroadworksAPI
 
-BASIC_API_PARAMS = {
-    "host": "localhost",
-    "username": "username@example.com",
-    "password": "password",
-    "session_id": "00000000-1111-2222-3333-444444444444",
-}
-
-api = BroadworksAPI(**BASIC_API_PARAMS)
+api = BroadworksAPI(
+    host="localhost",
+    username="username@example.com",
+    password="password",
+    session_id="00000000-1111-2222-3333-444444444444",
+)
 
 
 def canon_xml(inxml):
